Documentation
¶
Overview ¶
Package v1beta1 contains API Schema definitions for the Halkyon Capability v1beta1 API group +k8s:deepcopy-gen=package,register +groupName=halkyon.io
Index ¶
Constants ¶
const ( DatabaseCategory CapabilityCategory = "Database" PostgresType CapabilityType = "Postgres" MetricCategory CapabilityCategory = "Metric" LoggingCategory CapabilityCategory = "Logging" )
const Kind string = "Capability"
Variables ¶
var ( // SchemeGroupVersion is the group version used to register these objects. SchemeGroupVersion = schema.GroupVersion{Group: api.GroupName, Version: api.V1Beta1Version} // AddToScheme is a function which adds this version to a scheme AddToScheme = schemeBuilder.AddToScheme )
Functions ¶
This section is empty.
Types ¶
type Capability ¶
type Capability struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec CapabilitySpec `json:"spec,omitempty"`
Status CapabilityStatus `json:"status,omitempty"`
}
Capability is the Schema for the Services API +k8s:openapi-gen=true +genclient
func (*Capability) DeepCopy ¶
func (in *Capability) DeepCopy() *Capability
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Capability.
func (*Capability) DeepCopyInto ¶
func (in *Capability) DeepCopyInto(out *Capability)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*Capability) DeepCopyObject ¶
func (in *Capability) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*Capability) GetGroupVersionKind ¶
func (in *Capability) GetGroupVersionKind() schema.GroupVersionKind
type CapabilityCategory ¶
type CapabilityCategory string
func (CapabilityCategory) Equals ¶
func (cc CapabilityCategory) Equals(other CapabilityCategory) bool
func (CapabilityCategory) String ¶
func (cc CapabilityCategory) String() string
type CapabilityList ¶
type CapabilityList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []Capability `json:"items"`
}
CapabilityList contains a list of Capability
func (*CapabilityList) DeepCopy ¶
func (in *CapabilityList) DeepCopy() *CapabilityList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CapabilityList.
func (*CapabilityList) DeepCopyInto ¶
func (in *CapabilityList) DeepCopyInto(out *CapabilityList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*CapabilityList) DeepCopyObject ¶
func (in *CapabilityList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type CapabilitySpec ¶
type CapabilitySpec struct {
/*
category: <database>, <logging>,<metrics>
type: postgres (if category is database)
version: <version of the DB or prometheus or ...> to be installed
secretName: <secret_name_to_be_created> // Is used by kubedb postgres and is optional as some capability provider does not need to create a secret
parameters:
// LIST OF PARAMETERS WILL BE MAPPED TO EACH CATEGORY !
- name: DB_USER // WILL BE USED TO CREATE THE DB SECRET
value: "admin"
- name: DB_PASSWORD // WILL BE USED TO CREATE THE DB SECRET
value: "admin"
*/
Category CapabilityCategory `json:"category"`
Type CapabilityType `json:"type"`
Version string `json:"version"`
Parameters []v1beta1.NameValuePair `json:"parameters,omitempty"`
}
CapabilitySpec defines the desired state of Capability +k8s:openapi-gen=true
func (*CapabilitySpec) DeepCopy ¶
func (in *CapabilitySpec) DeepCopy() *CapabilitySpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CapabilitySpec.
func (*CapabilitySpec) DeepCopyInto ¶
func (in *CapabilitySpec) DeepCopyInto(out *CapabilitySpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (CapabilitySpec) Matches ¶
func (in CapabilitySpec) Matches(requested CapabilitySpec) bool
type CapabilityStatus ¶
type CapabilityStatus struct {
// INSERT ADDITIONAL STATUS FIELD - define observed state of cluster
// Important: Run "operator-sdk generate k8s" to regenerate code after modifying this file
// Add custom validation using kubebuilder tags: https://book.kubebuilder.io/beyond_basics/generating_crd.html
v1beta1.Status
}
CapabilityStatus defines the observed state of Capability +k8s:openapi-gen=true
func (*CapabilityStatus) DeepCopy ¶
func (in *CapabilityStatus) DeepCopy() *CapabilityStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CapabilityStatus.
func (*CapabilityStatus) DeepCopyInto ¶
func (in *CapabilityStatus) DeepCopyInto(out *CapabilityStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type CapabilityType ¶
type CapabilityType string
func (CapabilityType) Equals ¶
func (ct CapabilityType) Equals(other CapabilityType) bool
func (CapabilityType) String ¶
func (ct CapabilityType) String() string